##########################################################################
#                                                                        # #
# Licensed Materials - Property of HCL                                   #   #
# Restricted Material of HCL                                             #######
# HCL OneTest Embedded                                                         #
# � Copyright HCL Technologies. 2020 All Rights Reserved.                      #
#                                                                              #
# US Government Users Restricted Rights - Use, duplication or                  #
# disclosure restricted by GSA ADP Schedule Contract with HCL Technologies.    #
#                                                                              #
################################################################################

my $VERBOSE_MODE=$ENV{ATTOLSTUDIO_VERBOSE};
sub mySystem {
    my( $OS, $ROSERT_HOST );

    $OS          = '?' unless $OS          = $ENV{'OS'};
    $ROSERT_HOST = '?' unless $ROSERT_HOST = $ENV{'ROSERT_HOST'};
    if ($VERBOSE_MODE) {
        print STDERR "====================================\n";
        print STDERR "system call @_\n";
        print STDERR "location : \n";
        system("pwd");
        print STDERR "====================================\n";
    }
    if(($ROSERT_HOST eq 'win32') && ($OS !~ m{^Windows_NT$}i )) {
        return system( join( ' ', @_ ) );
    } else {
        return system( @_ );
    }
}

my $status = 0;

sub convertFdc {
    # plug transition coverage call
    if (-d $RTIST_ADDITIONAL_FDC) {
        # directory already exists
    } else {
        mkdir $RTIST_ADDITIONAL_FDC;
    }
    my @command = ();
    push @command, "RTistFdcConv";
    push @command, "\"$RTIST_TARGET_BUILD\"";
    push @command, "\"$RTIST_ADDITIONAL_FDC\"";
    push @command, "\"$RTIST_EMX_FILES\"";
    $status = &mySystem( @command );
    if (opendir (DIR, $RTIST_ADDITIONAL_FDC)) {
        if (-e $RTIST_TEMPORARY_FDC) {
            # tmp directory already exists
        } else {
            mkdir $RTIST_TEMPORARY_FDC
        } 
        while (my $file = readdir(DIR)) {    
            if ($file =~ m/(.*)\.fdc$/i) {
                # save original fdc                
                if (-e $RTIST_TARGET_BUILD."/".$file) {    
                    if (-e $RTIST_TEMPORARY_FDC."/".$file) {
                        # already exists
                    } else {
                        copy($RTIST_TARGET_BUILD."/".$file, $RTIST_TEMPORARY_FDC."/".$file);
                    }
                }
                # replace it with modified one
                copy($RTIST_ADDITIONAL_FDC."/".$file, $RTIST_TARGET_BUILD."/".$file);
            }            
        } 
        closedir(DIR);
    }    
}

###### specific post processing steps for model colorization #############

# Warning : do not rename or change this prototype, it overwrites placeholder from Tools.pl
my $rtistCovColorModelVerbose=0;

sub modelPost {
    my $colorFile=$RTIST_TARGET_COLORIZATION;   #generated file
	my $modelFDCdir=$RTIST_TARGET_BUILD; #diretory where are the FDC model files 
    my @paramFDC;
    
    convertFdc();
    
	opendir(DIR,"$modelFDCdir");
    my @dirContents = readdir(DIR);
    closedir(DIR);
	foreach my $file (@dirContents) {
		push(@paramFDC,"\"".$modelFDCdir.'/'.$file."\"") if($file =~m/\.fdc$/i);
	}
	print &PerlTranslate("rtistCovColorModel.pl", "color Report Generation...\n");
	my $command="attolcov ".join(' ',@paramFDC,"\"".$ATC_TIO_NAME."\"")." -block -output=model_cov.txt >>modelCov.log";
	print "$command\n";
    my $relative_tcjs=$RTIST_APP_TCJS_FILE;
    my $relativeworkspace="platform:/resource";
    $relative_tcjs=~s/$WORKSPACE_PATH/$relativeworkspace/e;
    $relative_tcjs=~s/ /%20/g;
	my $status=SystemP($command);
	if($status==0){
		if(open(IN,"model_cov.txt")){
			open(OU,">$colorFile");
            print OU "TC_URI ".$relative_tcjs."\n"; 
			my $found='';
			my $result='';
			my $count=' ';
			my $lookingForCount=0;
			while(<IN>) {
				if (/^\s*(.*\.(emx|efx)#.*)\s*:$/){
                   $found=$1;
                   $found=~s/%2520/%20/g; # BoZ : temporary hack until fdcconv is fixed
                }
				elsif($lookingForCount){#find the count number on line following 'Statement block'
					$lookingForCount=0;
					$count='';
					#             /, line 1, 2 time(s)
					if(/^\s*\/,\sline\s\d,\s(\d+)\stime/){
						$count=$1.' ';
					}
					print OU $result, $count, $found, "\n"; 
 					print $result, $count, $found, "\n" if($rtistCovColorModelVerbose); 
				}
				elsif (/^\s*Statement blocks\s/ && ($found ne '')) # this line should immediately follow emx ref
				{
					$result='UNCOVERED ';
					if (/^\s*Statement blocks\s*\.+\s*\d+\.\d\%\s*\((\d+)\/(\d+)\)/) { #print;
						if($1 != 0) {
							$result= 'COVERED ';
							$lookingForCount=1;#find the count number if any, on line following 'Statement block' then print result
						}
						else
						{
							print OU $result, $found, "\n"; 
							print $result, $found, "\n" if($rtistCovColorModelVerbose); 
						}
					}
				} 
				else
				{
					$found='';
				}
			} 
            #clean up (close handlers / delete temp files)
            close IN; 
            close OU;
            RegisterGenFiles("COR $colorFile"); 
			unlink("model_cov.txt","modelCov.log");
		}
	}

    if ($status != 0 ) { 
        print &PerlTranslate("rtistCovColorModel.pl", "Failed.\n"); 
    } else { 
        print &PerlTranslate("rtistCovColorModel.pl", "Done.\n");
    }
    return $status;   
}

1;

